@@ -18,7 +18,9 @@
  * <http://www.gnu.org/licenses/>.
  */
 
+#include "config.h"
 #include <err.h>
+#include <stdarg.h>
 #include <stdlib.h>
 #include <string.h>
 #include <unistd.h>
@@ -28,21 +30,18 @@
 curldata_t *curldata_calloc(void)
 {
     curldata_t *c = calloc(1, sizeof(curldata_t));
-    if (!c)
-    {
+    if (!c) {
         warn("curldata_calloc: calloc failed");
         return NULL;
     }
     c->body = strdup("");
-    if (!c->body)
-    {
+    if (!c->body) {
         warn("curldata_calloc: strdup failed");
         free(c);
         return NULL;
     }
     c->headers = strdup("");
-    if (!c->headers)
-    {
+    if (!c->headers) {
         warn("curldata_calloc: strdup failed");
         free(c->body);
         free(c);
@@ -53,7 +52,8 @@ curldata_t *curldata_calloc(void)
 
 void curldata_free(curldata_t *c)
 {
-    if (!c) return;
+    if (!c)
+        return;
     free(c->body);
     free(c->headers);
     free(c);
@@ -63,8 +63,7 @@ static size_t curl_hcb(char *buf, size_t size, size_t n, void *userdata)
 {
     curldata_t *c = (curldata_t *)userdata;
     void *p = realloc(c->headers, c->headers_len + size * n + 1);
-    if (!p)
-    {
+    if (!p) {
         warn("curl_hcb: realloc failed");
         return 0;
     }
@@ -79,8 +78,7 @@ static size_t curl_wcb(void *ptr, size_t size, size_t n, void *userdata)
 {
     curldata_t *c = (curldata_t *)userdata;
     void *p = realloc(c->body, c->body_len + size * n + 1);
-    if (!p)
-    {
+    if (!p) {
         warn("curl_wcb: realloc failed");
         return 0;
     }
@@ -94,19 +92,16 @@ static size_t curl_wcb(void *ptr, size_t size, size_t n, void *userdata)
 curldata_t *curl_get(const char *url)
 {
     curldata_t *c = NULL;
-    for (int retry = 0; retry < 3; retry++)
-    {
+    for (int retry = 0; retry < 3; retry++) {
         CURL *curl;
         CURLcode res;
         curl = curl_easy_init();
-        if (!curl)
-        {
+        if (!curl) {
             warnx("curl_get: curl_easy_init failed");
             return NULL;
         }
         c = curldata_calloc();
-        if (!c)
-        {
+        if (!c) {
             warnx("curl_get: curldata_calloc failed");
             curl_easy_cleanup(curl);
             return NULL;
@@ -119,26 +114,20 @@ curldata_t *curl_get(const char *url)
         curl_easy_setopt(curl, CURLOPT_USERAGENT,
                 "uacme/" VERSION " (https://github.com/ndilieto/uacme)");
         res = curl_easy_perform(curl);
-        if (res != CURLE_OK)
-        {
+        if (res != CURLE_OK) {
             warnx("curl_get: GET %s failed: %s", url,
                     curl_easy_strerror(res));
             curldata_free(c);
             c = NULL;
-        }
-        else
-        {
+        } else {
             long code = -1;
             curl_easy_getinfo(curl, CURLINFO_RESPONSE_CODE, &code);
             c->code = code;
         }
         curl_easy_cleanup(curl);
         if (c)
-        {
             break;
-        }
-        else if (retry < 3)
-        {
+        else if (retry < 3) {
             warnx("curl_get: waiting 5 seconds before retrying");
             sleep(5);
         }
@@ -146,23 +135,22 @@ curldata_t *curl_get(const char *url)
     return c;
 }
 
-curldata_t *curl_post(const char *url, const char *post)
+curldata_t *curl_post(const char *url, void *post_data, size_t post_size,
+        const char *header, ...)
 {
+    va_list ap;
     curldata_t *c = NULL;
-    for (int retry = 0; retry < 3; retry++)
-    {
+    for (int retry = 0; retry < 3; retry++) {
         CURL *curl;
         CURLcode res;
         struct curl_slist *list = NULL;
         curl = curl_easy_init();
-        if (!curl)
-        {
+        if (!curl) {
             warnx("curl_post: curl_easy_init failed");
             return NULL;
         }
         c = curldata_calloc();
-        if (!c)
-        {
+        if (!c) {
             warnx("curl_post: curldata_calloc failed");
             curl_easy_cleanup(curl);
             return NULL;
@@ -174,31 +162,31 @@ curldata_t *curl_post(const char *url, const char *post)
         curl_easy_setopt(curl, CURLOPT_HEADERDATA, c);
         curl_easy_setopt(curl, CURLOPT_USERAGENT,
                 "uacme/" VERSION " (https://github.com/ndilieto/uacme)");
-        curl_easy_setopt(curl, CURLOPT_POSTFIELDS, post);
-        list = curl_slist_append(list, "Content-Type: application/jose+json");
+        curl_easy_setopt(curl, CURLOPT_POSTFIELDS, post_data);
+        curl_easy_setopt(curl, CURLOPT_POSTFIELDSIZE, post_size);
+        va_start(ap, header);
+        while (header) {
+            list = curl_slist_append(list, header);
+            header = va_arg(ap, const char *);
+        }
+        va_end(ap);
         curl_easy_setopt(curl, CURLOPT_HTTPHEADER, list);
         res = curl_easy_perform(curl);
         curl_slist_free_all(list);
-        if (res != CURLE_OK)
-        {
+        if (res != CURLE_OK) {
             warnx("curl_post: POST %s failed: %s", url,
                     curl_easy_strerror(res));
             curldata_free(c);
             c = NULL;
-        }
-        else
-        {
+        } else {
             long code = -1;
             curl_easy_getinfo(curl, CURLINFO_RESPONSE_CODE, &code);
             c->code = code;
         }
         curl_easy_cleanup(curl);
         if (c)
-        {
             break;
-        }
-        else if (retry < 3)
-        {
+        else if (retry < 3) {
             warnx("curl_post: waiting 5 seconds before retrying");
             sleep(5);
         }
